==> ejc-bfyjerp-impl-3.0.0-20241107.102109-19-sources.jar: com/ejianc/business/bid/bean/BidPersonAffirmEntity.java <==
package com.ejianc.business.bid.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 投标管理-确认标书员
 * 
 * @author generator
 * 
 */
 @TableName("ejc_bid_person_affirm")
public class BidPersonAffirmEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 编码
    @TableField(value="registration_id")
    private Long registrationId; // 项目报名表Id
    @TableField(value="opportunity_id")
    private Long opportunityId; // 商机登记表Id
    @TableField(value="opportunity_bill_code")
    private Long opportunityBillCode; // 商机登记单据编码
    @TableField(value="engineering_name")
    private String engineeringName; // 工程名称
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="bid_person_id")
    private Long bidPersonId; // 标书员id
    @TableField(value="bid_person_name")
    private String bidPersonName; // 标书员名称
    @TableField(value="bid_person_code")
    private String bidPersonCode; // 标书员编码
    @TableField(value="budget_person_id")
    private Long budgetPersonId; // 预算员id
    @TableField(value="budget_person_name")
    private String budgetPersonName; // 预算员名称
    @TableField(value="budget_person_code")
    private String budgetPersonCode; // 预算员编码
    @TableField(value="budget_fee")
    private BigDecimal budgetFee; // 预算费用
    @TableField(value="employee_id")
    private Long employeeId; // 编制人id
    @TableField(value="employee_name")
    private String employeeName; // 编制人名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="commit_date")
    private Date commitDate; // 提交日期
    @TableField(value="commit_user_name")
    private String commitUserName; // 提交人名称
    @TableField(value="commit_user_code")
    private String commitUserCode; // 提交人账号
    @TableField(value="effective_date")
    private Date effectiveDate; // 生效日期
    
    
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getRegistrationId() {
        return registrationId;
    }

    public void setRegistrationId(Long registrationId) {
        this.registrationId = registrationId;
    }
    public Long getOpportunityId() {
        return opportunityId;
    }

    public void setOpportunityId(Long opportunityId) {
        this.opportunityId = opportunityId;
    }
    public Long getOpportunityBillCode() {
        return opportunityBillCode;
    }

    public void setOpportunityBillCode(Long opportunityBillCode) {
        this.opportunityBillCode = opportunityBillCode;
    }
    public String getEngineeringName() {
        return engineeringName;
    }

    public void setEngineeringName(String engineeringName) {
        this.engineeringName = engineeringName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getBidPersonId() {
        return bidPersonId;
    }

    public void setBidPersonId(Long bidPersonId) {
        this.bidPersonId = bidPersonId;
    }
    public String getBidPersonName() {
        return bidPersonName;
    }

    public void setBidPersonName(String bidPersonName) {
        this.bidPersonName = bidPersonName;
    }
    public String getBidPersonCode() {
        return bidPersonCode;
    }

    public void setBidPersonCode(String bidPersonCode) {
        this.bidPersonCode = bidPersonCode;
    }
    public Long getBudgetPersonId() {
        return budgetPersonId;
    }

    public void setBudgetPersonId(Long budgetPersonId) {
        this.budgetPersonId = budgetPersonId;
    }
    public String getBudgetPersonName() {
        return budgetPersonName;
    }

    public void setBudgetPersonName(String budgetPersonName) {
        this.budgetPersonName = budgetPersonName;
    }
    public String getBudgetPersonCode() {
        return budgetPersonCode;
    }

    public void setBudgetPersonCode(String budgetPersonCode) {
        this.budgetPersonCode = budgetPersonCode;
    }
    public BigDecimal getBudgetFee() {
        return budgetFee;
    }

    public void setBudgetFee(BigDecimal budgetFee) {
        this.budgetFee = budgetFee;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Date getCommitDate() {
        return commitDate;
    }

    public void setCommitDate(Date commitDate) {
        this.commitDate = commitDate;
    }
    public String getCommitUserName() {
        return commitUserName;
    }

    public void setCommitUserName(String commitUserName) {
        this.commitUserName = commitUserName;
    }
    public String getCommitUserCode() {
        return commitUserCode;
    }

    public void setCommitUserCode(String commitUserCode) {
        this.commitUserCode = commitUserCode;
    }
    public Date getEffectiveDate() {
        return effectiveDate;
    }

    public void setEffectiveDate(Date effectiveDate) {
        this.effectiveDate = effectiveDate;
    }
    
}

==> ejc-bfyjerp-impl-3.0.0-20241119.015209-41-sources.jar: com/ejianc/business/bid/bean/BidPersonAffirmEntity.java <==
package com.ejianc.business.bid.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 投标管理-确认标书员
 * 
 * @author generator
 * 
 */
 @TableName("ejc_bid_person_affirm")
public class BidPersonAffirmEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 编码
    @TableField(value="registration_id")
    private Long registrationId; // 项目报名表Id
    @TableField(value="opportunity_id")
    private Long opportunityId; // 商机登记表Id
    @TableField(value="opportunity_bill_code")
    private Long opportunityBillCode; // 商机登记单据编码
    @TableField(value="engineering_name")
    private String engineeringName; // 工程名称
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="bid_person_id")
    private Long bidPersonId; // 标书员id
    @TableField(value="bid_person_name")
    private String bidPersonName; // 标书员名称
    @TableField(value="bid_person_code")
    private String bidPersonCode; // 标书员编码
    @TableField(value="budget_person_id")
    private Long budgetPersonId; // 预算员id
    @TableField(value="budget_person_name")
    private String budgetPersonName; // 预算员名称
    @TableField(value="budget_person_code")
    private String budgetPersonCode; // 预算员编码
    @TableField(value="budget_fee")
    private BigDecimal budgetFee; // 预算费用
    @TableField(value="employee_id")
    private Long employeeId; // 编制人id
    @TableField(value="employee_name")
    private String employeeName; // 编制人名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="commit_date")
    private Date commitDate; // 提交日期
    @TableField(value="commit_user_name")
    private String commitUserName; // 提交人名称
    @TableField(value="commit_user_code")
    private String commitUserCode; // 提交人账号
    @TableField(value="effective_date")
    private Date effectiveDate; // 生效日期
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_code")
    private String orgCode; // 所属组织编码
    @TableField(value="org_name")
    private String orgName; // 所属组织名称

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getRegistrationId() {
        return registrationId;
    }

    public void setRegistrationId(Long registrationId) {
        this.registrationId = registrationId;
    }
    public Long getOpportunityId() {
        return opportunityId;
    }

    public void setOpportunityId(Long opportunityId) {
        this.opportunityId = opportunityId;
    }
    public Long getOpportunityBillCode() {
        return opportunityBillCode;
    }

    public void setOpportunityBillCode(Long opportunityBillCode) {
        this.opportunityBillCode = opportunityBillCode;
    }
    public String getEngineeringName() {
        return engineeringName;
    }

    public void setEngineeringName(String engineeringName) {
        this.engineeringName = engineeringName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getBidPersonId() {
        return bidPersonId;
    }

    public void setBidPersonId(Long bidPersonId) {
        this.bidPersonId = bidPersonId;
    }
    public String getBidPersonName() {
        return bidPersonName;
    }

    public void setBidPersonName(String bidPersonName) {
        this.bidPersonName = bidPersonName;
    }
    public String getBidPersonCode() {
        return bidPersonCode;
    }

    public void setBidPersonCode(String bidPersonCode) {
        this.bidPersonCode = bidPersonCode;
    }
    public Long getBudgetPersonId() {
        return budgetPersonId;
    }

    public void setBudgetPersonId(Long budgetPersonId) {
        this.budgetPersonId = budgetPersonId;
    }
    public String getBudgetPersonName() {
        return budgetPersonName;
    }

    public void setBudgetPersonName(String budgetPersonName) {
        this.budgetPersonName = budgetPersonName;
    }
    public String getBudgetPersonCode() {
        return budgetPersonCode;
    }

    public void setBudgetPersonCode(String budgetPersonCode) {
        this.budgetPersonCode = budgetPersonCode;
    }
    public BigDecimal getBudgetFee() {
        return budgetFee;
    }

    public void setBudgetFee(BigDecimal budgetFee) {
        this.budgetFee = budgetFee;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Date getCommitDate() {
        return commitDate;
    }

    public void setCommitDate(Date commitDate) {
        this.commitDate = commitDate;
    }
    public String getCommitUserName() {
        return commitUserName;
    }

    public void setCommitUserName(String commitUserName) {
        this.commitUserName = commitUserName;
    }
    public String getCommitUserCode() {
        return commitUserCode;
    }

    public void setCommitUserCode(String commitUserCode) {
        this.commitUserCode = commitUserCode;
    }
    public Date getEffectiveDate() {
        return effectiveDate;
    }

    public void setEffectiveDate(Date effectiveDate) {
        this.effectiveDate = effectiveDate;
    }
    
}
